Documentation
¶
Overview ¶
Package consensus implements different Shx consensus engines.
Index ¶
Constants ¶
const (
MinerNumber = 8
)
const NodeCheckpointInterval = 200
Variables ¶
var ( // ErrUnknownAncestor is returned when validating a block requires an ancestor // that is unknown. ErrUnknownAncestor = errors.New("unknown ancestor") // ErrFutureBlock is returned when a block's timestamp is in the future according // to the current node. ErrFutureBlock = errors.New("block in the future") // ErrInvalidNumber is returned if a block's number doesn't equal it's parent's // plus one. ErrInvalidNumber = errors.New("invalid block number") // extra-data ErrMissingVanity = errors.New("extra-data 32 byte vanity prefix missing") ErrMissingSignature = errors.New("extra-data 65 byte suffix signature missing") ErrExtraSigners = errors.New("non-checkpoint block contains extra signer list") ErrInvalidMixDigest = errors.New("non-zero mix digest") ErrInvalidUncleHash = errors.New("non empty uncle hash") ErrInvalidTimestamp = errors.New("invalid timestamp") ErrWaitTransactions = errors.New("waiting for transactions") ErrUnknownBlock = errors.New("unknown block") ErrInvalidCheckpointBeneficiary = errors.New("beneficiary in checkpoint block non-zero") ErrInvalidVote = errors.New("vote nonce not 0x00..0 or 0xff..f") // vote nonce in checkpoint block non-zero ErrInvalidCheckpointVote = errors.New("vote nonce in checkpoint block non-zero") // reject block but do not drop peer ErrInvalidblockbutnodrop = errors.New("reject block but do not drop peer") // bad param ErrBadParam = errors.New("input bad param") Errnilparam = errors.New("input param is nil") ErrNoLastBlock = errors.New("No Last Block when verify during the fullsync") )
var ( Zeroaddr = common.HexToAddress("0x0000000000000000000000000000000000000000") ExtraVanity = 32 // Fixed number of extra-data prefix bytes reserved for signerHash vanity ExtraSeal = 65 // Fixed number of extra-data suffix bytes reserved for signerHash seal )
var (
IgnoreRetErr = false //ignore finalize return err
)
Functions ¶
Types ¶
type ChainReader ¶
type ChainReader interface {
// Config retrieves the blockchain's chain configuration.
Config() *config.ChainConfig
// CurrentHeader retrieves the current header from the local chain.
CurrentHeader() *types.Header
// GetHeader retrieves a block header from the database by hash and number.
GetHeader(hash common.Hash, number uint64) *types.Header
// GetHeaderByNumber retrieves a block header from the database by number.
GetHeaderByNumber(number uint64) *types.Header
// GetHeaderByash retrieves a block header from the database by its hash.
GetHeaderByHash(hash common.Hash) *types.Header
// GetBlock retrieves a block from the database by hash and number.
GetBlock(hash common.Hash, number uint64) *types.Block
StateAt(root common.Hash) (*state.StateDB, error)
}
ChainReader defines a small collection of methods needed to access the local blockchain during header and/or uncle verification.
type Engine ¶
type Engine interface {
// generate
PrepareBlockHeader(chain ChainReader, header *types.Header, state *state.StateDB) error
// GerateProof return a workproof
GenerateProof(chain ChainReader, header *types.Header, parent *types.Header, txs types.Transactions, proofs types.ProofStates) (*types.WorkProof, error)
SignData(data []byte) ([]byte, error)
RecoverSender(data []byte, signature []byte) (common.Address, error)
// VerifyProof check the proof from peer is correct, and return new hash.
VerifyProof(addr common.Address, lastHash common.Hash, proof *types.WorkProof) (common.Hash, error)
VerifyState(coinbase common.Address, history *set.Set, proof *types.WorkProof) bool
VerifyProofQuick(lasthash common.Hash, txroot common.Hash, newHash common.Hash) error
// Finalize runs any post-transaction state modifications
// and assembles the final block.
// Note: The block header and state database might be updated to reflect any
// consensus rules that happen at finalization.
Finalize(chain ChainReader, header *types.Header, state *state.StateDB, txs []*types.Transaction,
proofs []*types.ProofState, receipts []*types.Receipt) (*types.Block, error)
// Seal generates a new block for the given input block with the local miner's
// seal place on top.
GenBlockWithSig(chain ChainReader, block *types.Block) (*types.Block, error)
// Author retrieves the Shx address of the account that minted the given
// block, which may be different from the header's coinbase if a consensus
// engine is based on signatures.
Author(header *types.Header) (common.Address, error)
// VerifyHeader checks whether a header conforms to the consensus rules of a
// given engine. Verifying the seal may be done optionally here, or explicitly
// via the VerifySeal method.
VerifyHeader(chain ChainReader, header *types.Header, seal bool, mode config.SyncMode) error
// VerifyHeaders is similar to VerifyHeader, but verifies a batch of headers
// concurrently. The method returns a quit channel to abort the operations and
// a results channel to retrieve the async verifications (the order is that of
// the input slice).
VerifyHeaders(chain ChainReader, headers []*types.Header, seals []bool, mode config.SyncMode) (chan<- struct{}, <-chan error)
// APIs returns the RPC APIs this consensus engine provides.
APIs(chain ChainReader) []rpc.API
}
Engine is an algorithm agnostic consensus engine.
Directories
¶
| Path | Synopsis |
|---|---|
|
puppeth is a command to assemble networks configure.
|
puppeth is a command to assemble networks configure. |
Click to show internal directories.
Click to hide internal directories.